%define afsvers 1.3.82
%define pkgrel 3.SL

# Determine presence of rpmbuild command line --define arguments used for
# option specification
# These include:
# (*) Specify kernel version to build modules against:
#       --define "kernel 2.4.20-1.1931.2.231.2.11.ent"
# (*) Request building of userspace tools
#       --define "build_userspace 1"
# (*) Request building of kernel modules
#       --define "build_modules 1"
%{!?kernel: %define kernel %(uname -r)}
%define smp %(echo %{kernel} | grep -q smp && echo 1 || echo 0)
%define kvers %(echo %kernel | sed 's/smp//')

%define build_userspace_on_cmdline %{?build_userspace:1}%{!?build_userspace:0}
%define build_modules_on_cmdline %{?build_modules:1}%{!?build_modules:0}

# This is where to look for kernel build include files.
#
%define kbase /lib/modules
%define kxmoddir %{kbase}/%{kernel}
%define ksrcdir %{kxmoddir}/build

# Set 'debugspec' to 1 if you want to debug the spec file.  This will
# not remove the installed tree as part of the %clean operation
%define debugspec 0

# Set 'krb5support' to 1 if you want to build the openafs-krb5 package
# to distribute aklog and asetkey
%define krb5support 1

# OpenAFS configuration options
%define enable_bitmap_later 1
%define enable_bos_restricted_mode 1
%define enable_bos_new_config 1
%define enable_fast_restart 1
%define enable_supergroups 1
%define enable_largefile_fileserver 1

# Define the location of your init.d directory
%define initdir /etc/init.d

# Define the location of the PAM security module directory
%define pamdir /%{_lib}/security

# Define the default size (in KB) and the location of the client cache
%define defcachesize 100000
%define defcachedir /var/cache/openafs

# Determine which elements of OpenAFS to build.  For non-x86 arches
# (subject to the ExclusiveArch setting, below), we build both userspace
# and modules.  For most x86 arches, we build just the kernel modules.  For
# i386, we build just the userspace.  If you're running an i386 kernel,
# you'll need to tweak that last bit.
%if !%{build_userspace_on_cmdline} && !%{build_modules_on_cmdline}
%ifarch x86_64 ia64
%define build_userspace 1
%define build_modules 1
%endif
%ifarch %{ix86}
%define build_userspace 0
%define build_modules 1
%endif
%ifarch i386
%define build_userspace 1
%define build_modules 0
%endif
%endif

# deal with cmdline specification
%if %{build_userspace_on_cmdline} || %{build_modules_on_cmdline}
%if !%{build_userspace_on_cmdline}
%define build_userspace 0
%endif
%if !%{build_modules_on_cmdline}
%define build_modules 0
%endif
%endif

#######################################################################
# You probably don't need to change anything beyond this line
# NOTE: If you do, please email me!!!

# Make sure RPM doesn't complain about installed but non-packaged files.
#%define __check_files  %{nil}

Summary: OpenAFS distributed filesystem
Name: openafs
Version: %{afsvers}
Release: %{pkgrel}
Epoch: 0
Copyright: IBM Public License
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Vendor: Scientific Linux
Group: Networking/Filesystems
ExclusiveArch: %{ix86} x86_64 ia64

BuildRequires: pam-devel
%if %smp
BuildRequires: kernel-smp-devel = %{kvers}
%else
BuildRequires: kernel-devel = %{kvers}
%endif

Source0: http://www.openafs.org/dl/openafs/${afsvers}/openafs-%{afsvers}-src.tar.bz2
Source1: http://www.openafs.org/dl/openafs/${afsvers}/openafs-%{afsvers}-doc.tar.bz2
Source2: openafs-SL-ThisCell
Source3: openafs-SL-CellServDB
Source4: openafs-SL-SuidCells
Source6: openafs-afsmodname
Source8: openafs-README
Source12: openafs-CellAlias

Source20: openafs-krb5-2.0.tar.gz

Source30: http://www.tu-chemnitz.de/urz/afs/openafs/download/suse-7.2/SOURCES/openafs-killafs

Source40: openafs-rc

# next two shall be OK for all 1.3 series 
Patch100: openafs-1.3-afs.rc.linux.patch
Patch101: openafs-1.3-afs.rc.linux-df-Pk.patch
#
# 64 bit bug of aklog & Co. Thanks to Chris Wing <wingc@engin.umich.edu>
Patch103: openafs-krb5-64bit.patch

Patch104: openafs-krb5-SL4.patch

Patch204: openafs-SL-krb5-configure-amd64.patch

# for the debug package
Patch301: openafs-1.2.10-twiddle.patch
Patch302: openafs-1.3.78-afsdumpscan-acls.patch

# fix cache coherency issues w/ 1.3.82, hopefully not needed in later versions:
Patch1001: vnode-dentry-backout.patch

%description
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides common files shared across all the various
OpenAFS packages but are not necessarily tied to a client or server.

###############################################################################
#
# build the userspace side of things if so requested
#
###############################################################################
%if %{build_userspace}

%package client
Requires: binutils, openafs-kernel, openafs = %{PACKAGE_VERSION}
Summary: OpenAFS Filesystem Client
Group: Networking/Filesystem

%description client
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides basic client support to mount and manipulate
AFS.

%package server
Requires: openafs-kernel, openafs = %{PACKAGE_VERSION}
Summary: OpenAFS Filesystem Server
Group: Networking/Filesystems

%description server
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides basic server support to host files in an AFS
Cell.

%package devel
Summary: OpenAFS Development Libraries and Headers
Group: Development/Filesystems

%description devel
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides static development libraries and headers needed
to compile AFS applications.  Note: AFS currently does not provide
shared libraries.

%package debug
Summary: OpenAFS additional debugging utilities
Group: Networking/Filesystems

%description debug
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides additional tools useful for understanding and
debugging the client and server. It is completely optional.

%endif
#build_userspace
###############################################################################
#
# build the kernel modules if so requested
#
###############################################################################
%if %{build_modules}

%package -n kernel-module-openafs-%{kernel}
Summary: OpenAFS Kernel Module for kernel %kernel
Requires: openafs >= %{PACKAGE_VERSION}
%ifarch ia64
Requires: /boot/efi/EFI/redhat/vmlinuz-%{kernel}
%else
Requires: /boot/vmlinuz-%{kernel}
%endif
Requires: modutils
Provides: openafs-kernel
Provides: kernel-module-openafs = %{epoch}:%{version}-%{release}
Group: Networking/Filesystems

%description -n kernel-module-openafs-%{kernel}
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides an openafs kernel module for
kernel %{kernel} and architecture %{_target_cpu}.

%endif
#build modules

%package kernel-source
Summary: OpenAFS Kernel Module source tree
Group: Networking/Filesystems

%description kernel-source
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides the source code to build your own AFS kernel
module.

%package compat
Summary: OpenAFS client compatibility symlinks
Requires: openafs = %{PACKAGE_VERSION}, openafs-client = %{PACKAGE_VERSION}
Group: Networking/Filesystems
Obsoletes: openafs-client-compat

%description compat
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides compatibility symlinks in /usr/afsws.  It is
completely optional, and is only necessary to support legacy
applications and scripts that hard-code the location of AFS client
programs.

%package kpasswd
Summary: OpenAFS KA kpasswd support
Requires: openafs
Group: Networking/Filesystems

%description kpasswd
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides the compatibility symlink for kpasswd, in case
you are using KAserver instead of Krb5.

%if %{krb5support}
%package krb5
Summary: OpenAFS programs to use with krb5
Requires: openafs = %{PACKAGE_VERSION}
Group: Networking/Filesystems
BuildRequires: krb5-devel

%description krb5
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides compatibility programs so you can use krb5
to authenticate to AFS services, instead of using AFS's homegrown
krb4 lookalike services.
%endif

###############################################################################
#
# preparation
#
###############################################################################

%prep

: @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
: @@@
: @@@ kernel version:     %{kernel}
: @@@ kernel modules dir: %{kxmoddir}
: @@@ kernel RPM version: kernel-module-openafs-%{kernel}
: @@@ PAM modules dir:    %{pamdir}
: @@@ build userspace:    %{build_userspace}
: @@@ build modules:      %{build_modules}
: @@@ arch:               %{_arch}
: @@@ target cpu:         %{_target_cpu}
: @@@
: @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

%setup -q -b 1
%setup -q -T -D -a 20

#%patch100 -p1
#%patch101 -p1

# this will hopefully vanish with releases >= 1.3.83
%patch1001

%ifarch x86_64 ia32e
 %if %{krb5support}
%patch103 -p0
%patch204 -p1
 %endif
%endif

%if %{krb5support}
%patch104 -p0
%endif

%patch301 -p0
%patch302 -p1

###############################################################################
#
# building
#
###############################################################################

%build

kv='26'

case %{_arch} in
        x86_64|ia32e)                   sysname=amd64_linux${kv}        ;;
        i386|i486|i586|i686|athlon)     sysname=i386_linux${kv}         ;;
        *)                              sysname=%{_arch}_linux${kv}     ;;
esac

# is this needed for 1.3 ? Jarek.
# not sure. Stephan ;-)
#%ifarch x86_64
#perl -pi -e 's,^(XCFLAGS.*),\1 -fPIC,' src/config/Makefile.amd64_linux24.in
#perl -pi -e 's,^(XLIBS.*),\1 -lresolv,' src/config/Makefile.amd64_linux24.in
#%endif

config_opts=" \
%if %{enable_bitmap_later}
	--enable-bitmap-later \
%endif
%if %{enable_bos_restricted_mode}
	--enable-bos-restricted-mode \
%endif
%if %{enable_fast_restart}
	--enable-fast-restart \
%endif
%if %{enable_bos_new_config}
	--enable-bos-new-config \
%endif
%if %{enable_supergroups}
	--enable-supergroups \
%endif
%if %{enable_largefile_fileserver}
	--enable-largefile-fileserver \
%endif
	--enable-transarc-paths"

# Configure AFS

CFLAGS="$RPM_OPT_FLAGS"; export CFLAGS

# On some platforms, static libraries must be built with -fPIC before we can
# link them into shared objects.  Because the PAM module uses the libraries,
# we need to build them with -fPIC.  This is one way to do it.
%ifarch x86_64
CFLAGS="$CFLAGS -fPIC"; export CFLAGS
%endif


./configure --with-afs-sysname=${sysname} \
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--bindir=%{_bindir} \
	--sbindir=%{_sbindir} \
	--with-linux-kernel-headers=%{ksrcdir} \
	$config_opts \
	|| exit 1

%if %{build_userspace}
# Build the user-space AFS stuff
make dest_nolibafs || exit 1

# Build the libafs tree
make only_libafs_tree || exit 1

%if %{krb5support}
# Now build aklog/asetkey

(cd afs-krb5/src &&
        ./configure --prefix=/usr --with-krb5=/usr/kerberos \
            --with-afs=`pwd`/../../${sysname}/dest/ && \
        make all PROGS="asetkey aklog ka-forwarder" && \
        touch afs2k5db && touch fakeka && \
        make install PROGS="asetkey aklog ka-forwarder" \
            DESTDIR=`pwd`/../../${sysname}/dest/ INSTALL_BIN=/bin \
            INSTALL_SBIN=/etc) || exit 1
%endif

# additional debugging tools

make -C src/venus twiddle
make -C src/venus whatfid
make -C src/tests dumptool
make -C src/tests afsdump_scan
make -C src/tests afsdump_extract
make -C src/vol   vol-bless

%endif
#build_userspace

%if %{build_modules}
make dest_only_libafs

# terrible hack to work around broken build on 1.3.80:
#make dest_only_libafs || {
#    ln -s ../make_kbuild_makefile.pl src/libafs/MODLOAD-*
#    make dest_only_libafs
#}

%endif

###############################################################################
#
# installation
#
###############################################################################

%install
[ $RPM_BUILD_ROOT != / ] && rm -rf $RPM_BUILD_ROOT

kv='26'

case %{_arch} in
        x86_64|ia32e)                   sysname=amd64_linux${kv}        ;;
        i386|i486|i586|i686|athlon)     sysname=i386_linux${kv}         ;;
        *)                              sysname=%{_arch}_linux${kv}     ;;
esac
 
# Build install tree
%if %{build_userspace}
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
mkdir -p $RPM_BUILD_ROOT%{_libdir}
mkdir -p $RPM_BUILD_ROOT/etc/sysconfig
mkdir -p $RPM_BUILD_ROOT%{initdir}
mkdir -p $RPM_BUILD_ROOT/etc/openafs
mkdir -p $RPM_BUILD_ROOT%{pamdir}
mkdir -p $RPM_BUILD_ROOT%{_prefix}/afs/logs
mkdir -p $RPM_BUILD_ROOT%{_prefix}/afs/debug
mkdir -p $RPM_BUILD_ROOT%{_prefix}/vice/etc
mkdir -p $RPM_BUILD_ROOT%{defcachedir}
chmod 700 $RPM_BUILD_ROOT%{defcachedir}


# Copy files from dest to the appropriate places in BuildRoot
tar cf - -C ${sysname}/dest bin include | tar xf - -C $RPM_BUILD_ROOT%{_prefix}
tar cf - -C ${sysname}/dest/lib . | tar xf - -C $RPM_BUILD_ROOT%{_libdir}
tar cf - -C ${sysname}/dest/etc . | tar xf - -C $RPM_BUILD_ROOT%{_sbindir}
tar cf - -C ${sysname}/dest/root.server%{_prefix}/afs bin | tar xf - -C $RPM_BUILD_ROOT%{_prefix}/afs
tar cf - -C ${sysname}/dest/root.client%{_prefix}/vice/etc afsd C | tar xf - -C $RPM_BUILD_ROOT%{_prefix}/vice/etc

# Link kpasswd to kapasswd
mv -f $RPM_BUILD_ROOT%{_bindir}/kpasswd $RPM_BUILD_ROOT%{_bindir}/kpasswd.openafs
ln -f $RPM_BUILD_ROOT%{_bindir}/kpasswd.openafs $RPM_BUILD_ROOT%{_bindir}/kapasswd
mv -f $RPM_BUILD_ROOT%{_bindir}/pagsh $RPM_BUILD_ROOT%{_bindir}/pagsh.openafs


# Copy root.client config files
install -m 755 ${sysname}/dest/root.client%{_prefix}/vice/etc/afs.conf $RPM_BUILD_ROOT/etc/sysconfig/afs

# change default configuration
perl -pi -e 's/^CACHESIZE=.*/CACHESIZE=%{defcachesize}/' \
	$RPM_BUILD_ROOT/etc/sysconfig/afs
perl -pi -e 's@^CACHEDIR=.*@CACHEDIR=%{defcachedir}@' \
	$RPM_BUILD_ROOT/etc/sysconfig/afs

# Copy PAM modules
install -m 755 ${sysname}/dest/lib/pam* $RPM_BUILD_ROOT%{pamdir}

# PAM symlinks
ln -sf pam_afs.so.1 $RPM_BUILD_ROOT%{pamdir}/pam_afs.so
ln -sf pam_afs.krb.so.1 $RPM_BUILD_ROOT%{pamdir}/pam_afs.krb.so


uve=$RPM_BUILD_ROOT%{_prefix}/vice/etc
install -p -m 644 %{SOURCE2} $uve/ThisCell
install -p -m 644 %{SOURCE12} $uve/CellAlias
install -p -m 644 %{SOURCE3} $uve/CellServDB
install -p -m 644 %{SOURCE4} $uve/SuidCells
echo "afs:%{defcachedir}:%{defcachesize}" > $uve/cacheinfo
chmod 644 $uve/cacheinfo
#
install -p -m 755 %{SOURCE30} $uve/killafs

# extra debugging tools

mkdir -p $RPM_BUILD_ROOT%{_prefix}/afs/debug
for i in \
    src/viced/cbd \
    src/viced/fsprobe \
    src/viced/check_sysid \
    src/auth/setkey \
    src/fsprobe/fsprobe_test \
    src/rxdebug/rxdumptrace \
    src/venus/twiddle \
    src/venus/whatfid \
    src/venus/test/getinitparams \
    src/tests/dumptool \
    src/tests/afsdump_scan \
    src/tests/afsdump_extract \
    src/ubik/utst_client \
    src/ubik/utst_server \
    src/vlserver/cnvldb \
    src/vlserver/vlclient \
    src/vol/vol-bless \
    src/ptserver/readgroup \
    src/ptserver/readpwd \
    src/ptserver/testpt \
    src/ptserver/db_verify \
    src/kauth/rebuild \
    ;do
  strip $i || true
  install -p -m 755 $i $RPM_BUILD_ROOT%{_prefix}/afs/debug
done

#
# LWP versions of servers (default is the pthread version)
#

install -p -m 755 src/viced/fileserver $RPM_BUILD_ROOT%{_prefix}/afs/bin/fileserver.lwp
install -p -m 755 src/volser/volserver $RPM_BUILD_ROOT%{_prefix}/afs/bin/volserver.lwp

#
# pthreaded version of butc (LWP is still the default)
#

install -p -m 755 src/tbutc/butc $RPM_BUILD_ROOT%{_prefix}/sbin/butc.pthread

#
# install kernel-source
#

# Install the kernel module source tree
mkdir -p $RPM_BUILD_ROOT%{_prefix}/src/openafs-kernel-%{afsvers}/src
tar cf - -C libafs_tree . | \
        tar xf - -C $RPM_BUILD_ROOT%{_prefix}/src/openafs-kernel-%{afsvers}/src

# Next, copy the LICENSE Files, README
install -m 644 src/LICENSE $RPM_BUILD_ROOT%{_prefix}/src/openafs-kernel-%{afsvers}/LICENSE.IBM
install -m 644 %{SOURCE8} $RPM_BUILD_ROOT%{_prefix}/src/openafs-kernel-%{afsvers}/README

# init script is a separate source now, the patches grew a bit large:
#install -m 755 src/afsd/afs.rc.linux $RPM_BUILD_ROOT/etc/init.d/afs
install -m 755 %{SOURCE40} $RPM_BUILD_ROOT/etc/init.d/afs

#
# Install DOCUMENTATION
#

# Build the DOC directory
mkdir -p $RPM_BUILD_ROOT/$RPM_DOC_DIR/openafs-%{afsvers}
tar cf - -C doc LICENSE html pdf | \
    tar xf - -C $RPM_BUILD_ROOT/$RPM_DOC_DIR/openafs-%{afsvers}


#
# create filelist
#
grep -v "^#" >openafs-file-list <<EOF-openafs-file-list
%{_bindir}/afsmonitor
%{_bindir}/bos
%{_bindir}/fs
# in openafs-kpasswd
#%{_bindir}/kapasswd
#
#%{_bindir}/kpasswd
%{_bindir}/klog
%{_bindir}/klog.krb
%{_bindir}/pagsh.openafs
%{_bindir}/pagsh.krb
%{_bindir}/pts
%{_bindir}/scout
%{_bindir}/sys
%{_bindir}/livesys
%{_bindir}/tokens
%{_bindir}/tokens.krb
%{_bindir}/translate_et
%{_bindir}/udebug
%{_bindir}/unlog
%{_sbindir}/backup
%{_sbindir}/butc
%{_sbindir}/butc.pthread
%{_sbindir}/fms
%{_sbindir}/fstrace
%{_sbindir}/kas
%{_sbindir}/kdump
%{_sbindir}/read_tape
%{_sbindir}/restorevol
%{_sbindir}/rxdebug
%{_sbindir}/uss
%{_sbindir}/vos
EOF-openafs-file-list

#
# Install compatiblity links
#
for d in bin:bin etc:sbin; do
  olddir=`echo $d | sed 's/:.*$//'`
  newdir=`echo $d | sed 's/^.*://'`
  mkdir -p $RPM_BUILD_ROOT%{_prefix}/afsws/$olddir
  for f in `cat openafs-file-list`; do
    if echo $f | grep -q /$newdir/; then
      fb=`basename $f`
      ln -sf %{_prefix}/$newdir/$fb $RPM_BUILD_ROOT%{_prefix}/afsws/$olddir/$fb
    fi
  done
done

%endif
#build_userspace

%if %{build_modules}

srcdir=${sysname}/dest/root.client/usr/vice/etc/modload
%if %smp
modname=libafs-%{kernel}.mp.ko
%else
modname=libafs-%{kernel}.ko
%endif

# sigh. ia64 still has an SMP kernel only, which is not called ...smp
%ifarch ia64
modname=libafs-%{kernel}.mp.ko
%endif

dstdir=$RPM_BUILD_ROOT/%{kxmoddir}/kernel/fs/openafs
mkdir -p ${dstdir}
install -m 644 ${srcdir}/${modname} ${dstdir}/libafs.ko

%endif
#build_modules

%clean
rm -f openafs-file-list
[ "$RPM_BUILD_ROOT" != "/" -a "x%{debugspec}" != "x1" ] && \
	rm -fr $RPM_BUILD_ROOT


###############################################################################
###
### scripts
###
###############################################################################
%if %{build_userspace}

%post
# If afs was configured already: don't touch
# if not add to config but disable
/sbin/chkconfig --list afs > /dev/null 2>&1
if [ $? -ne 0 ]; then
 /sbin/chkconfig --add afs
 # Add afs but put it off.
 /sbin/chkconfig --level 345 afs off
fi
#if [ -x /usr/sbin/chstk ]; then
# /usr/sbin/chstk -e /sbin/insmod
#fi

%post client
if [ ! -d /afs ]; then
	mkdir /afs
	chown root.root /afs
	chmod 0755 /afs
fi

echo
echo The AFS cache is configured for %{defcachesize} KB. Edit the 
echo /usr/vice/etc/cacheinfo file to change this before
echo running AFS for the first time. You should also
echo set your home cell in /usr/vice/etc/ThisCell.
echo
echo Also, you may want to edit /etc/pam.d/login and 
echo possibly others there to get an AFS token on login.
echo Put the line:
echo 
echo    auth       sufficient   /lib/security/pam_afs.so try_first_pass ignore_root
echo
echo before the one for pwdb.
echo

%post server
if [ -f /etc/sysconfig/afs ] ; then
	srv=`grep ^AFS_SERVER /etc/sysconfig/afs | sed 's/^AFS_SERVER[\s]*=[\s]*//'`
	if [ "x$srv" = "xon" ] ; then
		exit 0
	fi
fi

echo
echo Be sure to edit /etc/sysconfig/afs and turn AFS_SERVER on
echo

%preun
if [ $1 = 0 ] ; then
        %{initdir}/afs stop
        chkconfig --del afs
	[ -d /afs ] && rmdir /afs
fi

%endif
#build_userspace

%if %{build_modules}

%post -n kernel-module-openafs-%{kernel}

depmod -ae %{kernel} >/dev/null 2>&1 || :
%endif
#build_modules

###############################################################################
###
### file lists
###
###############################################################################
%if %{build_userspace}
%files -f openafs-file-list
%defattr(-,root,root)
%config(noreplace) /etc/sysconfig/afs
%doc %{_docdir}/openafs-%{afsvers}
%{initdir}/afs

%files client
%defattr(-,root,root)
%dir %{_prefix}/vice
%dir %{_prefix}/vice/etc
%config %{_prefix}/vice/etc/CellServDB
%config(noreplace) %{_prefix}/vice/etc/CellAlias
%config(noreplace) %{_prefix}/vice/etc/SuidCells
%config(noreplace) %{_prefix}/vice/etc/ThisCell
%config(noreplace) %{_prefix}/vice/etc/cacheinfo
%{_bindir}/cmdebug
%{_bindir}/up
%{_prefix}/vice/etc/afsd
%{_prefix}/vice/etc/killafs
%{pamdir}/pam_afs.krb.so.1
%{pamdir}/pam_afs.krb.so
%{pamdir}/pam_afs.so.1
%{pamdir}/pam_afs.so
%dir %{defcachedir}

%files server
%defattr(-,root,root)
%dir %{_prefix}/afs
%dir %{_prefix}/afs/bin
%dir %{_prefix}/afs/logs
%{_prefix}/afs/bin/bosserver
%{_prefix}/afs/bin/buserver
%{_prefix}/afs/bin/fileserver
%{_prefix}/afs/bin/fileserver.lwp
# Should we support KAServer?
%{_prefix}/afs/bin/kaserver
%{_prefix}/afs/bin/kpwvalid
%{_prefix}/afs/bin/pt_util
%{_prefix}/afs/bin/ptserver
%{_prefix}/afs/bin/salvager
%{_prefix}/afs/bin/upclient
%{_prefix}/afs/bin/upserver
%{_prefix}/afs/bin/vlserver
%{_prefix}/afs/bin/volinfo
%{_prefix}/afs/bin/volserver
%{_prefix}/afs/bin/volserver.lwp
%{_sbindir}/prdb_check
%{_sbindir}/vldb_check
%{_sbindir}/vldb_convert

%files devel
%defattr(-,root,root)
%{_bindir}/rxgen
%{_includedir}/afs
%{_includedir}/des.h
%{_includedir}/des_conf.h
%{_includedir}/des_odd.h
%{_includedir}/lock.h
%{_includedir}/lwp.h
%{_includedir}/mit-cpyright.h
%{_includedir}/potpourri.h
%{_includedir}/preempt.h
%{_includedir}/rx
%{_includedir}/timer.h
%{_includedir}/ubik.h
%{_includedir}/ubik_int.h
%{_libdir}/afs
%{_libdir}/libafsauthent.a
%{_libdir}/libafsrpc.a
%{_libdir}/libdes.a
%{_libdir}/liblwp.a
%{_libdir}/librx.a
%{_libdir}/librxkad.a
%{_libdir}/librxstat.a
%{_libdir}/libubik.a

%files kernel-source
%defattr(-,root,root)
%{_prefix}/src/openafs-kernel-%{afsvers}/LICENSE.IBM
%{_prefix}/src/openafs-kernel-%{afsvers}/README
%{_prefix}/src/openafs-kernel-%{afsvers}/src

%files compat
%defattr(-,root,root)
%{_prefix}/afsws

%files kpasswd
%defattr(-,root,root)
%{_bindir}/kapasswd
%{_bindir}/kpasswd.openafs
%{_bindir}/kpwvalid

%if %{krb5support}
%files krb5
%defattr(-,root,root)
%{_bindir}/aklog
%{_sbindir}/asetkey
%endif

%files debug
%defattr(-,root,root)
%{_prefix}/afs/debug
%{_prefix}/vice/etc/C

%endif
#build_userspace

%if %{build_modules}
%files -n kernel-module-openafs-%{kernel}
%defattr(-,root,root)
%{kxmoddir}/kernel/fs/openafs/libafs.ko
%endif

###############################################################################
###
### openafs.spec change log
###
###############################################################################

%changelog
* Tue May 03 2005 Stephan Wiesand <stephan.wiesand@desy.de> 1.3.82-3.SL
- added a patch (1001) from Jason McCormick <jasonmc@cert.org> to fix
  cache coherence issues with this release

* Mon May 02 2005 Stephan Wiesand <stephan.wiesand@desy.de> 1.3.82-2.SL
- added missing ia64 changes by Jarek from 1.3.80-2.SL (kernel requirement,
  module built is .mp.ko, not .ko)
- turned off leftover debugspec

* Sat Apr 30 2005 Stephan Wiesand <stephan.wiesand@desy.de> 1.3.82-1.SL
- new upstream release fixing linux 2.6 issues including the first write
  access hanging on x86/UP
- hopefully guessed right about the fix for ia64 module build (by Jarek
  for 1.3.80-2.SL, but could not find the srpm)
- made the init script a separate source file
- in init script, do not run the on_network check if ENABLE_DYNROOT=1
- package the LWP builds of fileserver & volserver (which are built but
  not installed by default) in addition to the default pthreaded ones,
  with suffix ".lwp"
- package the pthread build of butc in addition to the default LWP one,
  with suffix ".pthread"
- disable patch101 (obsoleted by upstream hack)
- removed the build hack from 1.3.80-1.SL, fixed upstream

* Tue Mar 22 2005 Stephan Wiesand <stephan.wiesand@desy.de> 1.3.80-1.SL
- new upstream version supposed to fix many problems on linux 2.6
- notice the default afsd behaviour finally has changed to -nosettime;
  add -settime to your afsd options to get back the old behaviour
- added an ugly hack to get the kernel modules built
- updated CellServDB to version from grand.central.org as of today

* Tue Mar 01 2005 Stephan Wiesand <stephan.wiesand@desy.de> 1.3.79-4.SL
- made default cache location and size macros, removed cacheinfo source5,
  generate cacheinfo in install instead
- fixed default cache size to 100MB again, resurrected the message
  in -client's post, changed default location to /var/cache/openafs
- removed unused source21 (kernel-version.sh)
- changed last afs-krb5 build patch (patch configure, not configure.in,
  and do not wipe out 64bit patch to configure by rerunning autoconf)

* Sun Feb 27 2005 Stephan Wiesand <stephan.wiesand@desy.de> 1.3.79-3.SL
- this version is SL4/1.3 only
- get afs-krb5 going
- removed tons of old cruft & patches no longer used
- adapt module build to kernel[-smp]-devel: we now require this to be
  installed, and will only build the module package for a single kernel
  defined on the command line, or the running one in none is defined
  (this gets rid of all that redhat-buildsys voodoo which seems broken
   on SL4 anyway)
- added livesys & kdump executables to main package
- added optional openafs-debug package with additional tools
- made module name in package & init script libafs instead of openafs,
  since that's what the module registers as anyway (modprobe -r openafs
  would fail)
- added a patch (101) to fix the CACHESIZE=AUTOMATIC behaviour when the cache
  is mounted on some device with a long name

* Sat Feb 26 2005  Jaroslaw Polok <jaroslaw.polok@cern.ch>
- initial attempt at build for SL 4. (2.6 kernel)

* Fri Feb 18 2005  Jaroslaw Polok <jaroslaw.polok@cern.ch>
- added build of ia32e kernel module

* Mon Jan 31 2005  Troy Dawson <dawson@fnal.gov> 15.12.SL
- All changes came from Stephan Wiesand.  Many thanks for his pointers
- afsd options chaned in spec file
- /etc/sysconfig/afs set to be %config(noreplace)
- requires wget
- removed openafs-compat %pre scripts
- Added CellAlias file, with commented out example

* Wed Jan 19 2005  Troy Dawson <dawson@fnal.gov> 15.11.SL
- Put LC_ALL=C into the startup server test. This helps with 
  internationalization. Submitted by Jaroslaw Polok

* Mon Jan 17 2005 Enrico M.V. Fasanelli <enrico@le.infn.it> 15.10.SL
- applied patch from Chris Wing for 64bit aklog & Co.

* Thu Aug 12 2004  Troy Dawson <dawson@fnal.gov> 15.7.SL
- Put -fakestat in as a default option

* Tue Aug 10 2004  Troy Dawson <dawson@fnal.gov> 15.6.SL
- Updated CellServDB
- Put -dynroot in as a default option

* Sat Jun 19 2004  Troy Dawson <dawson@fnal.gov> 15.4.SL
- Made more changes to startup script. Does sanity checks of ThisCell

* Fri Jun 18 2004  Troy Dawson <dawson@fnal.gov> 15.3.SL
- Made change to /etc/init.d/afs startup script

* Sun May 30 2004 Jaroslaw.Polok@cern.ch
- rebuilt for Scientific Linux without site-specific setup
- kerberos 5 enabled in build
* Fri Apr 16 2004  Jaroslaw.Polok@cern.ch
- changed packaging of modules again: to followup Fedora Core
  (draft) rules and allow yum/apt/up2date to handle these

* Tue Apr 06 2004  Jaroslaw.Polok@cern.ch
- changed packaging of modules

* Sun Feb 22 2004  Jaroslaw.Polok@cern.ch
- Rebuilt for CERN E. Linux (ix86/ia64/x86_64)

* Thu Sep  4 2003  David Howells <dhowells@redhat.com>> 1.2.10-4
- don't use rpm from within spec file as this can cause problems

* Wed Sep  3 2003  David Howells <dhowells@redhat.com> 1.2.10-4
- added ia64 to the ExclusiveArch list

* Fri Aug 29 2003  <David Howells <dhowells@redhat.com>> 1.2.10-3
- get rid of a %%else that causes problems with rpm-4.0.4

* Fri Aug 22 2003  David Howells <dhowells@redhat.com> 1.2.10-3
- added rpmbuild cmdline defines to control which bits to build

* Wed Aug 20 2003  Nalin Dahyabhai <nalin@redhat.com>
- obey CFLAGS set at configure-time on i386/x86_64 linux
- openafs-krb5: look in $krb5_prefix/lib64 for Kerberos libraries if they are
  not found in $krb5_prefix/lib
- build the modules for PAM on x86_64
- when checking for res_search, try to link with it instead of checking for it
  in libraries, in case it's a macro or redefined by a macro
- use %%{ix86} instead of %%{all_x86} where appropriate
- install AFS libraries into %%{_libdir} instead of %%{_prefix}/lib

* Fri Aug 15 2003  <David Howells <dhowells@redhat.com>> 1.2.10-3
- permit the kernel-to-build-against to be selected by cmdline argument to
  rpmbuild if preferred

* Thu Aug 14 2003  Nalin Dahyabhai <nalin@redhat.com>
- fix compilation of openafs-krb5 bits against krb5 1.3

* Mon Aug 11 2003  <David Howells <dhowells@redhat.com>> 1.2.10-2
- got rid of all rpmlint errors
- delete certain tags (Packager/Vendor/Distribution)

* Fri Aug  8 2003  <David Howells <dhowells@redhat.com>> 1.2.10-1
- Adapted OpenAFS version 1.2.10 to compile in beehive

